@@ -1,4 +1,8 @@
 import json
+from FLog.LOGGER import Log
+from FSON import dictSort
+
+Log = Log("FCoRE.DICT")
 
 """
 -> "dict" object extension/helper functions
@@ -26,7 +30,7 @@ def get(key: str, dic, default=False):
                 return result
         return default
     except Exception as e:
-        print(f"Failed to get key for dict error=[ {e} ]")
+        Log.d(f"Failed to get key for dict error=[ {e} ]")
         return default
 
 def get_all_keys(dic, *keys, force_type=None) -> []:
@@ -87,7 +91,7 @@ def replace_key_value(dictIn, key, value):
         result[key] = value
         return result
     except Exception as e:
-        print(f"Could not replace key/value pair in dict. error=[ {e} ]")
+        Log.d(f"Could not replace key/value pair in dict. error=[ {e} ]")
         return dictIn
 
 def replace_in_dict(input, variables):
@@ -130,7 +134,7 @@ def remove_key_value(key, dic: dict) -> dict:
         del dic[key]
         return dic
     except Exception as e:
-        print(f"Failed to delete key value error=[ {e} ]")
+        Log.d(f"Failed to delete key value error=[ {e} ]")
         return dic
 
 def add_key_value(key, value, dic: dict, forceListAsValue=False) -> dict:
@@ -168,6 +172,10 @@ def to_key_list(data: dict) -> list:
         temp_list.append(key)
     return temp_list
 
+""" JSON """
+def dumps(data: dict, indent=4, sort_keys=True, default=str):
+    return json.dumps(data, sort_keys=sort_keys, indent=indent, default=default)
+
 """ Export """
 def to_pretty_json(data: dict, indent=4):
     obj = json.dumps(data, sort_keys=True, indent=indent, default=str)
@@ -175,7 +183,7 @@ def to_pretty_json(data: dict, indent=4):
 
 """ Sorting """
 def order_by_value(dic: dict) -> dict:
-    return {k: v for k, v in sorted(dic.items(), key=lambda item: item[1], reverse=True)}
+    return dictSort.SORT_BY_VALUE(dic)
 
 """ Tiffany Specific """
 # -> Takes word count dicts and add the values into one count.
